@@ -381,24 +381,32 @@ int write_file(const char *filename, int selected_only) {
     write_string("\ndo_not_include_H_from_C");
   if(use_FL_COMMAND)
     write_string("\nuse_FL_COMMAND");
+  if (utf8_in_src)
+    write_string("\nutf8_in_src");
   if (i18n_type) {
     write_string("\ni18n_type %d", i18n_type);
-    write_string("\ni18n_include %s", i18n_include);
+    write_string("\ni18n_include"); write_word(i18n_include);
+    write_string("\ni18n_conditional"); write_word(i18n_conditional);
     switch (i18n_type) {
     case 1 : /* GNU gettext */
-        write_string("\ni18n_function %s", i18n_function);
+        write_string("\ni18n_function"); write_word(i18n_function);
+        write_string("\ni18n_static_function"); write_word(i18n_static_function);
         break;
     case 2 : /* POSIX catgets */
-        if (i18n_file[0]) write_string("\ni18n_file %s", i18n_file);
-        write_string("\ni18n_set %s", i18n_set);
+        if (i18n_file[0]) write_string("\ni18n_file"); write_word(i18n_file);
+        write_string("\ni18n_set"); write_word(i18n_set);
         break;
     }
   }
-  shell_settings_write();
+
   if (!selected_only) {
     write_string("\nheader_name"); write_word(header_file_name);
     write_string("\ncode_name"); write_word(code_file_name);
 
+#if 0
+    // https://github.com/fltk/fltk/issues/328
+    // Project wide settings require a redesign.
+    shell_settings_write();
     if (shell_settings_windows.command) {
       write_string("\nwin_shell_cmd"); write_word(shell_settings_windows.command);
       write_string("\nwin_shell_flags"); write_string("%d", shell_settings_windows.flags);
@@ -411,7 +419,9 @@ int write_file(const char *filename, int selected_only) {
       write_string("\nmac_shell_cmd"); write_word(shell_settings_macos.command);
       write_string("\nmac_shell_flags"); write_string("%d", shell_settings_macos.flags);
     }
+#endif
   }
+
   for (Fl_Type *p = Fl_Type::first; p;) {
     if (!selected_only || p->selected) {
       p->write();
@@ -487,6 +497,10 @@ static void read_children(Fl_Type *p, int paste, Strategy strategy, char skip_op
         use_FL_COMMAND=1;
         goto CONTINUE;
       }
+      if (!strcmp(c,"utf8_in_src")) {
+        utf8_in_src=1;
+        goto CONTINUE;
+      }
       if (!strcmp(c,"i18n_type")) {
         i18n_type = atoi(read_word());
         goto CONTINUE;
@@ -495,6 +509,10 @@ static void read_children(Fl_Type *p, int paste, Strategy strategy, char skip_op
         i18n_function = fl_strdup(read_word());
         goto CONTINUE;
       }
+      if (!strcmp(c,"i18n_static_function")) {
+        i18n_static_function = fl_strdup(read_word());
+        goto CONTINUE;
+      }
       if (!strcmp(c,"i18n_file")) {
         i18n_file = fl_strdup(read_word());
         goto CONTINUE;
@@ -507,9 +525,8 @@ static void read_children(Fl_Type *p, int paste, Strategy strategy, char skip_op
         i18n_include = fl_strdup(read_word());
         goto CONTINUE;
       }
-      if (!strcmp(c,"i18n_type"))
-      {
-        i18n_type = atoi(read_word());
+      if (!strcmp(c,"i18n_conditional")) {
+        i18n_conditional = fl_strdup(read_word());
         goto CONTINUE;
       }
       if (!strcmp(c,"i18n_type"))
