@@ -41,6 +41,8 @@ void Fl_alert(int x, int y, const char *txt);
 
 int Fl_choice(int x, int y, const char *txt, const char *b0, const char *b1, const char *b2);
 
+int Fl_choice_n(int x, int y, const char *txt, const char *b0, const char *b1, const char *b2);
+
 const char *Fl_input(int x, int y, const char *txt, const char *deflt);
 
 const char *Fl_password(int x, int y, const char *txt, const char *deflt);
@@ -51,6 +53,8 @@ void Fl_alert2(const char *txt);
 
 int Fl_choice2(const char *txt, const char *b0, const char *b1, const char *b2);
 
+int Fl_choice2_n(const char *txt, const char *b0, const char *b1, const char *b2);
+
 const char *Fl_input2(const char *txt, const char *deflt);
 
 const char *Fl_password2(const char *txt, const char *deflt);
